﻿using SushiBarContracts.BindingModel;
using SushiBarContracts.ViewModels;
using SushiBarDataModels;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations.Schema;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace SushiBarDatabaseImplement.Models
{
    public class Implementer : IImplementerModel
    {
        public int Id { get; private set; }

        [Required]
        public string ImplementerFIO { get; private set; } = string.Empty;

        [Required]
        public string Password { get; private set; } = string.Empty;

        [Required]
        public int WorkExperience { get; private set; }

        [Required]
        public int Qualification { get; private set; }

        [Required]
        [ForeignKey("ImplementerId")]
        public virtual List<Order> Orders { get; set; } = new();

        public static Implementer? Create(ImplementerBindingModel? model)
        {
            if (model == null)
            {
                return null;
            }
            return new Implementer()
            {
                Id = model.Id,
                ImplementerFIO = model.ImplementerFIO,
                WorkExperience = model.WorkExperience,
                Password = model.Password,
                Qualification = model.Qualification,
            };
        }

        public void Update(ImplementerBindingModel? model)
        {
            if (model == null) return;
            ImplementerFIO = model.ImplementerFIO;
            WorkExperience = model.WorkExperience;
            Password = model.Password;
            Qualification = model.Qualification;
        }

        public ImplementerViewModel GetViewModel => new()
        {
            Id = Id,
            ImplementerFIO = ImplementerFIO,
            WorkExperience = WorkExperience,
            Password = Password,
            Qualification = Qualification,
        };
    }
}
